# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_connect_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_connect_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIcom/digitalasset/canton/sequencer/api/v30/sequencer_connect_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\"\xcd\x0b\n\x10SequencerConnect\x1a\xa8\x01\n\x10HandshakeRequest\x12\x38\n\x18\x63lient_protocol_versions\x18\x01 \x03(\x05R\x16\x63lientProtocolVersions\x12=\n\x18minimum_protocol_version\x18\x02 \x01(\x05H\x00R\x16minimumProtocolVersion\x88\x01\x01\x42\x1b\n\x19_minimum_protocol_version\x1a\xe8\x02\n\x11HandshakeResponse\x12\x36\n\x17server_protocol_version\x18\x01 \x01(\x05R\x15serverProtocolVersion\x12q\n\x07success\x18\x02 \x01(\x0b\x32U.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.HandshakeResponse.SuccessH\x00R\x07success\x12q\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32U.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.HandshakeResponse.FailureH\x00R\x07\x66\x61ilure\x1a\t\n\x07Success\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value\x1a\x1a\n\x18GetSynchronizerIdRequest\x1az\n\x19GetSynchronizerIdResponse\x12\x38\n\x18physical_synchronizer_id\x18\x01 \x01(\tR\x16physicalSynchronizerId\x12#\n\rsequencer_uid\x18\x02 \x01(\tR\x0csequencerUid\x1a\"\n GetSynchronizerParametersRequest\x1a\x9c\x01\n!GetSynchronizerParametersResponse\x12i\n\rparameters_v1\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.StaticSynchronizerParametersH\x00R\x0cparametersV1B\x0c\n\nparameters\x1a\x15\n\x13VerifyActiveRequest\x1a\xd6\x02\n\x14VerifyActiveResponse\x12t\n\x07success\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.VerifyActiveResponse.SuccessH\x00R\x07success\x12t\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32X.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.VerifyActiveResponse.FailureH\x00R\x07\x66\x61ilure\x1a&\n\x07Success\x12\x1b\n\tis_active\x18\x01 \x01(\x08R\x08isActive\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value\x1a\xa5\x01\n-RegisterOnboardingTopologyTransactionsRequest\x12t\n\x15topology_transactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x14topologyTransactions\x1a\x30\n.RegisterOnboardingTopologyTransactionsResponse2\x98\x08\n\x17SequencerConnectService\x12\xa8\x01\n\tHandshake\x12L.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.HandshakeRequest\x1aM.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.HandshakeResponse\x12\xc0\x01\n\x11GetSynchronizerId\x12T.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.GetSynchronizerIdRequest\x1aU.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.GetSynchronizerIdResponse\x12\xd8\x01\n\x19GetSynchronizerParameters\x12\\.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.GetSynchronizerParametersRequest\x1a].com.digitalasset.canton.sequencer.api.v30.SequencerConnect.GetSynchronizerParametersResponse\x12\xb1\x01\n\x0cVerifyActive\x12O.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.VerifyActiveRequest\x1aP.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.VerifyActiveResponse\x12\xff\x01\n&RegisterOnboardingTopologyTransactions\x12i.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.RegisterOnboardingTopologyTransactionsRequest\x1aj.com.digitalasset.canton.sequencer.api.v30.SequencerConnect.RegisterOnboardingTopologyTransactionsResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_connect_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_SEQUENCERCONNECT']._serialized_start=229
  _globals['_SEQUENCERCONNECT']._serialized_end=1714
  _globals['_SEQUENCERCONNECT_HANDSHAKEREQUEST']._serialized_start=250
  _globals['_SEQUENCERCONNECT_HANDSHAKEREQUEST']._serialized_end=418
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE']._serialized_start=421
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE']._serialized_end=781
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE_SUCCESS']._serialized_start=728
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE_SUCCESS']._serialized_end=737
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE_FAILURE']._serialized_start=739
  _globals['_SEQUENCERCONNECT_HANDSHAKERESPONSE_FAILURE']._serialized_end=772
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERIDREQUEST']._serialized_start=783
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERIDREQUEST']._serialized_end=809
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERIDRESPONSE']._serialized_start=811
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERIDRESPONSE']._serialized_end=933
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERPARAMETERSREQUEST']._serialized_start=935
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERPARAMETERSREQUEST']._serialized_end=969
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERPARAMETERSRESPONSE']._serialized_start=972
  _globals['_SEQUENCERCONNECT_GETSYNCHRONIZERPARAMETERSRESPONSE']._serialized_end=1128
  _globals['_SEQUENCERCONNECT_VERIFYACTIVEREQUEST']._serialized_start=1130
  _globals['_SEQUENCERCONNECT_VERIFYACTIVEREQUEST']._serialized_end=1151
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE']._serialized_start=1154
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE']._serialized_end=1496
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_SUCCESS']._serialized_start=1414
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_SUCCESS']._serialized_end=1452
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_FAILURE']._serialized_start=739
  _globals['_SEQUENCERCONNECT_VERIFYACTIVERESPONSE_FAILURE']._serialized_end=772
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSREQUEST']._serialized_start=1499
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSREQUEST']._serialized_end=1664
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSRESPONSE']._serialized_start=1666
  _globals['_SEQUENCERCONNECT_REGISTERONBOARDINGTOPOLOGYTRANSACTIONSRESPONSE']._serialized_end=1714
  _globals['_SEQUENCERCONNECTSERVICE']._serialized_start=1717
  _globals['_SEQUENCERCONNECTSERVICE']._serialized_end=2765
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...health.v30 import status_service_pb2 as _status_service_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParticipantStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ConnectedSynchronizer(_message.Message):
    __slots__ = ("physical_synchronizer_id", "health")
    class Health(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        HEALTH_UNSPECIFIED: _ClassVar[ConnectedSynchronizer.Health]
        HEALTH_HEALTHY: _ClassVar[ConnectedSynchronizer.Health]
        HEALTH_UNHEALTHY: _ClassVar[ConnectedSynchronizer.Health]
    HEALTH_UNSPECIFIED: ConnectedSynchronizer.Health
    HEALTH_HEALTHY: ConnectedSynchronizer.Health
    HEALTH_UNHEALTHY: ConnectedSynchronizer.Health
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    HEALTH_FIELD_NUMBER: _ClassVar[int]
    physical_synchronizer_id: str
    health: ConnectedSynchronizer.Health
    def __init__(self, physical_synchronizer_id: _Optional[str] = ..., health: _Optional[_Union[ConnectedSynchronizer.Health, str]] = ...) -> None: ...

class ParticipantStatusResponse(_message.Message):
    __slots__ = ("status", "not_initialized")
    class ParticipantStatusResponseStatus(_message.Message):
        __slots__ = ("common_status", "connected_synchronizers", "active", "supported_protocol_versions")
        COMMON_STATUS_FIELD_NUMBER: _ClassVar[int]
        CONNECTED_SYNCHRONIZERS_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        SUPPORTED_PROTOCOL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
        common_status: _status_service_pb2.Status
        connected_synchronizers: _containers.RepeatedCompositeFieldContainer[ConnectedSynchronizer]
        active: bool
        supported_protocol_versions: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, common_status: _Optional[_Union[_status_service_pb2.Status, _Mapping]] = ..., connected_synchronizers: _Optional[_Iterable[_Union[ConnectedSynchronizer, _Mapping]]] = ..., active: bool = ..., supported_protocol_versions: _Optional[_Iterable[int]] = ...) -> None: ...
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NOT_INITIALIZED_FIELD_NUMBER: _ClassVar[int]
    status: ParticipantStatusResponse.ParticipantStatusResponseStatus
    not_initialized: _status_service_pb2.NotInitialized
    def __init__(self, status: _Optional[_Union[ParticipantStatusResponse.ParticipantStatusResponseStatus, _Mapping]] = ..., not_initialized: _Optional[_Union[_status_service_pb2.NotInitialized, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from .openapi.client import AuthenticatedClient, Client

__all__ = ["Client", "AuthenticatedClient"]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReceivedCommitmentState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RECEIVED_COMMITMENT_STATE_UNSPECIFIED: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_MATCH: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_MISMATCH: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_BUFFERED: _ClassVar[ReceivedCommitmentState]
    RECEIVED_COMMITMENT_STATE_OUTSTANDING: _ClassVar[ReceivedCommitmentState]

class SentCommitmentState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SENT_COMMITMENT_STATE_UNSPECIFIED: _ClassVar[SentCommitmentState]
    SENT_COMMITMENT_STATE_MATCH: _ClassVar[SentCommitmentState]
    SENT_COMMITMENT_STATE_MISMATCH: _ClassVar[SentCommitmentState]
    SENT_COMMITMENT_STATE_NOT_COMPARED: _ClassVar[SentCommitmentState]
RECEIVED_COMMITMENT_STATE_UNSPECIFIED: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_MATCH: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_MISMATCH: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_BUFFERED: ReceivedCommitmentState
RECEIVED_COMMITMENT_STATE_OUTSTANDING: ReceivedCommitmentState
SENT_COMMITMENT_STATE_UNSPECIFIED: SentCommitmentState
SENT_COMMITMENT_STATE_MATCH: SentCommitmentState
SENT_COMMITMENT_STATE_MISMATCH: SentCommitmentState
SENT_COMMITMENT_STATE_NOT_COMPARED: SentCommitmentState

class LookupOffsetByTimeRequest(_message.Message):
    __slots__ = ("timestamp",)
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class LookupOffsetByTimeResponse(_message.Message):
    __slots__ = ("offset",)
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    offset: int
    def __init__(self, offset: _Optional[int] = ...) -> None: ...

class OpenCommitmentRequest(_message.Message):
    __slots__ = ("commitment", "physical_synchronizer_id", "computed_for_counter_participant_uid", "period_end_tick")
    COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    COMPUTED_FOR_COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    PERIOD_END_TICK_FIELD_NUMBER: _ClassVar[int]
    commitment: bytes
    physical_synchronizer_id: str
    computed_for_counter_participant_uid: str
    period_end_tick: _timestamp_pb2.Timestamp
    def __init__(self, commitment: _Optional[bytes] = ..., physical_synchronizer_id: _Optional[str] = ..., computed_for_counter_participant_uid: _Optional[str] = ..., period_end_tick: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OpenCommitmentResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class CommitmentContractMeta(_message.Message):
    __slots__ = ("cid", "reassignment_counter")
    CID_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_COUNTER_FIELD_NUMBER: _ClassVar[int]
    cid: bytes
    reassignment_counter: int
    def __init__(self, cid: _Optional[bytes] = ..., reassignment_counter: _Optional[int] = ...) -> None: ...

class InspectCommitmentContractsRequest(_message.Message):
    __slots__ = ("cids", "expected_synchronizer_id", "timestamp", "download_payload")
    CIDS_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    cids: _containers.RepeatedScalarFieldContainer[bytes]
    expected_synchronizer_id: str
    timestamp: _timestamp_pb2.Timestamp
    download_payload: bool
    def __init__(self, cids: _Optional[_Iterable[bytes]] = ..., expected_synchronizer_id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., download_payload: bool = ...) -> None: ...

class InspectCommitmentContractsResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class CommitmentContract(_message.Message):
    __slots__ = ("cid", "active_on_expected_synchronizer", "contract", "states")
    CID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_ON_EXPECTED_SYNCHRONIZER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    STATES_FIELD_NUMBER: _ClassVar[int]
    cid: bytes
    active_on_expected_synchronizer: bool
    contract: bytes
    states: _containers.RepeatedCompositeFieldContainer[ContractState.SynchronizerState]
    def __init__(self, cid: _Optional[bytes] = ..., active_on_expected_synchronizer: bool = ..., contract: _Optional[bytes] = ..., states: _Optional[_Iterable[_Union[ContractState.SynchronizerState, _Mapping]]] = ...) -> None: ...

class ContractState(_message.Message):
    __slots__ = ()
    class SynchronizerState(_message.Message):
        __slots__ = ("synchronizer_id", "created", "archived", "unassigned", "assigned", "unknown")
        SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
        CREATED_FIELD_NUMBER: _ClassVar[int]
        ARCHIVED_FIELD_NUMBER: _ClassVar[int]
        UNASSIGNED_FIELD_NUMBER: _ClassVar[int]
        ASSIGNED_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_FIELD_NUMBER: _ClassVar[int]
        synchronizer_id: str
        created: ContractState.Created
        archived: ContractState.Archived
        unassigned: ContractState.Unassigned
        assigned: ContractState.Assigned
        unknown: ContractState.Unknown
        def __init__(self, synchronizer_id: _Optional[str] = ..., created: _Optional[_Union[ContractState.Created, _Mapping]] = ..., archived: _Optional[_Union[ContractState.Archived, _Mapping]] = ..., unassigned: _Optional[_Union[ContractState.Unassigned, _Mapping]] = ..., assigned: _Optional[_Union[ContractState.Assigned, _Mapping]] = ..., unknown: _Optional[_Union[ContractState.Unknown, _Mapping]] = ...) -> None: ...
    class Created(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Assigned(_message.Message):
        __slots__ = ("reassignment_counter_target", "reassignment_id")
        REASSIGNMENT_COUNTER_TARGET_FIELD_NUMBER: _ClassVar[int]
        REASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
        reassignment_counter_target: int
        reassignment_id: ContractState.ReassignmentId
        def __init__(self, reassignment_counter_target: _Optional[int] = ..., reassignment_id: _Optional[_Union[ContractState.ReassignmentId, _Mapping]] = ...) -> None: ...
    class Archived(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Unassigned(_message.Message):
        __slots__ = ("target_synchronizer_id", "reassignment_counter_src", "reassignment_id")
        TARGET_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
        REASSIGNMENT_COUNTER_SRC_FIELD_NUMBER: _ClassVar[int]
        REASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
        target_synchronizer_id: str
        reassignment_counter_src: int
        reassignment_id: ContractState.ReassignmentId
        def __init__(self, target_synchronizer_id: _Optional[str] = ..., reassignment_counter_src: _Optional[int] = ..., reassignment_id: _Optional[_Union[ContractState.ReassignmentId, _Mapping]] = ...) -> None: ...
    class Unknown(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class ReassignmentId(_message.Message):
        __slots__ = ("id",)
        ID_FIELD_NUMBER: _ClassVar[int]
        id: str
        def __init__(self, id: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class LookupReceivedAcsCommitmentsRequest(_message.Message):
    __slots__ = ("time_ranges", "counter_participant_ids", "commitment_state", "verbose")
    TIME_RANGES_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_IDS_FIELD_NUMBER: _ClassVar[int]
    COMMITMENT_STATE_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    time_ranges: _containers.RepeatedCompositeFieldContainer[SynchronizerTimeRange]
    counter_participant_ids: _containers.RepeatedScalarFieldContainer[str]
    commitment_state: _containers.RepeatedScalarFieldContainer[ReceivedCommitmentState]
    verbose: bool
    def __init__(self, time_ranges: _Optional[_Iterable[_Union[SynchronizerTimeRange, _Mapping]]] = ..., counter_participant_ids: _Optional[_Iterable[str]] = ..., commitment_state: _Optional[_Iterable[_Union[ReceivedCommitmentState, str]]] = ..., verbose: bool = ...) -> None: ...

class LookupReceivedAcsCommitmentsResponse(_message.Message):
    __slots__ = ("received",)
    RECEIVED_FIELD_NUMBER: _ClassVar[int]
    received: _containers.RepeatedCompositeFieldContainer[ReceivedAcsCommitmentPerSynchronizer]
    def __init__(self, received: _Optional[_Iterable[_Union[ReceivedAcsCommitmentPerSynchronizer, _Mapping]]] = ...) -> None: ...

class TimeRange(_message.Message):
    __slots__ = ("from_exclusive", "to_inclusive")
    FROM_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    from_exclusive: _timestamp_pb2.Timestamp
    to_inclusive: _timestamp_pb2.Timestamp
    def __init__(self, from_exclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., to_inclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SynchronizerTimeRange(_message.Message):
    __slots__ = ("synchronizer_id", "interval")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    interval: TimeRange
    def __init__(self, synchronizer_id: _Optional[str] = ..., interval: _Optional[_Union[TimeRange, _Mapping]] = ...) -> None: ...

class Interval(_message.Message):
    __slots__ = ("start_tick_exclusive", "end_tick_inclusive")
    START_TICK_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    END_TICK_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    start_tick_exclusive: _timestamp_pb2.Timestamp
    end_tick_inclusive: _timestamp_pb2.Timestamp
    def __init__(self, start_tick_exclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_tick_inclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ReceivedAcsCommitment(_message.Message):
    __slots__ = ("interval", "origin_counter_participant_uid", "received_commitment", "own_commitment", "state")
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    OWN_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    interval: Interval
    origin_counter_participant_uid: str
    received_commitment: bytes
    own_commitment: bytes
    state: ReceivedCommitmentState
    def __init__(self, interval: _Optional[_Union[Interval, _Mapping]] = ..., origin_counter_participant_uid: _Optional[str] = ..., received_commitment: _Optional[bytes] = ..., own_commitment: _Optional[bytes] = ..., state: _Optional[_Union[ReceivedCommitmentState, str]] = ...) -> None: ...

class ReceivedAcsCommitmentPerSynchronizer(_message.Message):
    __slots__ = ("synchronizer_id", "received")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    received: _containers.RepeatedCompositeFieldContainer[ReceivedAcsCommitment]
    def __init__(self, synchronizer_id: _Optional[str] = ..., received: _Optional[_Iterable[_Union[ReceivedAcsCommitment, _Mapping]]] = ...) -> None: ...

class SentAcsCommitment(_message.Message):
    __slots__ = ("interval", "dest_counter_participant_uid", "own_commitment", "received_commitment", "state")
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    DEST_COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    OWN_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    interval: Interval
    dest_counter_participant_uid: str
    own_commitment: bytes
    received_commitment: bytes
    state: SentCommitmentState
    def __init__(self, interval: _Optional[_Union[Interval, _Mapping]] = ..., dest_counter_participant_uid: _Optional[str] = ..., own_commitment: _Optional[bytes] = ..., received_commitment: _Optional[bytes] = ..., state: _Optional[_Union[SentCommitmentState, str]] = ...) -> None: ...

class SentAcsCommitmentPerSynchronizer(_message.Message):
    __slots__ = ("synchronizer_id", "sent")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SENT_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    sent: _containers.RepeatedCompositeFieldContainer[SentAcsCommitment]
    def __init__(self, synchronizer_id: _Optional[str] = ..., sent: _Optional[_Iterable[_Union[SentAcsCommitment, _Mapping]]] = ...) -> None: ...

class LookupSentAcsCommitmentsRequest(_message.Message):
    __slots__ = ("time_ranges", "counter_participant_ids", "commitment_state", "verbose")
    TIME_RANGES_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_IDS_FIELD_NUMBER: _ClassVar[int]
    COMMITMENT_STATE_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    time_ranges: _containers.RepeatedCompositeFieldContainer[SynchronizerTimeRange]
    counter_participant_ids: _containers.RepeatedScalarFieldContainer[str]
    commitment_state: _containers.RepeatedScalarFieldContainer[SentCommitmentState]
    verbose: bool
    def __init__(self, time_ranges: _Optional[_Iterable[_Union[SynchronizerTimeRange, _Mapping]]] = ..., counter_participant_ids: _Optional[_Iterable[str]] = ..., commitment_state: _Optional[_Iterable[_Union[SentCommitmentState, str]]] = ..., verbose: bool = ...) -> None: ...

class LookupSentAcsCommitmentsResponse(_message.Message):
    __slots__ = ("sent",)
    SENT_FIELD_NUMBER: _ClassVar[int]
    sent: _containers.RepeatedCompositeFieldContainer[SentAcsCommitmentPerSynchronizer]
    def __init__(self, sent: _Optional[_Iterable[_Union[SentAcsCommitmentPerSynchronizer, _Mapping]]] = ...) -> None: ...

class SlowCounterParticipantSynchronizerConfig(_message.Message):
    __slots__ = ("synchronizer_ids", "distinguished_participant_uids", "threshold_distinguished", "threshold_default", "participant_uids_metrics")
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    DISTINGUISHED_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_DISTINGUISHED_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_UIDS_METRICS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    distinguished_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    threshold_distinguished: int
    threshold_default: int
    participant_uids_metrics: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer_ids: _Optional[_Iterable[str]] = ..., distinguished_participant_uids: _Optional[_Iterable[str]] = ..., threshold_distinguished: _Optional[int] = ..., threshold_default: _Optional[int] = ..., participant_uids_metrics: _Optional[_Iterable[str]] = ...) -> None: ...

class SetConfigForSlowCounterParticipantsRequest(_message.Message):
    __slots__ = ("configs",)
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[SlowCounterParticipantSynchronizerConfig]
    def __init__(self, configs: _Optional[_Iterable[_Union[SlowCounterParticipantSynchronizerConfig, _Mapping]]] = ...) -> None: ...

class SetConfigForSlowCounterParticipantsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetConfigForSlowCounterParticipantsRequest(_message.Message):
    __slots__ = ("synchronizer_ids",)
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetConfigForSlowCounterParticipantsResponse(_message.Message):
    __slots__ = ("configs",)
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[SlowCounterParticipantSynchronizerConfig]
    def __init__(self, configs: _Optional[_Iterable[_Union[SlowCounterParticipantSynchronizerConfig, _Mapping]]] = ...) -> None: ...

class CounterParticipantInfo(_message.Message):
    __slots__ = ("counter_participant_uid", "synchronizer_id", "intervals_behind", "behind_since", "as_of_sequencing_timestamp")
    COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    INTERVALS_BEHIND_FIELD_NUMBER: _ClassVar[int]
    BEHIND_SINCE_FIELD_NUMBER: _ClassVar[int]
    AS_OF_SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    counter_participant_uid: str
    synchronizer_id: str
    intervals_behind: int
    behind_since: _duration_pb2.Duration
    as_of_sequencing_timestamp: _timestamp_pb2.Timestamp
    def __init__(self, counter_participant_uid: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., intervals_behind: _Optional[int] = ..., behind_since: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., as_of_sequencing_timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetIntervalsBehindForCounterParticipantsRequest(_message.Message):
    __slots__ = ("counter_participant_ids", "synchronizer_ids", "threshold")
    COUNTER_PARTICIPANT_IDS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    counter_participant_ids: _containers.RepeatedScalarFieldContainer[str]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    threshold: int
    def __init__(self, counter_participant_ids: _Optional[_Iterable[str]] = ..., synchronizer_ids: _Optional[_Iterable[str]] = ..., threshold: _Optional[int] = ...) -> None: ...

class GetIntervalsBehindForCounterParticipantsResponse(_message.Message):
    __slots__ = ("intervals_behind",)
    INTERVALS_BEHIND_FIELD_NUMBER: _ClassVar[int]
    intervals_behind: _containers.RepeatedCompositeFieldContainer[CounterParticipantInfo]
    def __init__(self, intervals_behind: _Optional[_Iterable[_Union[CounterParticipantInfo, _Mapping]]] = ...) -> None: ...

class CountInFlightRequest(_message.Message):
    __slots__ = ("synchronizer_id",)
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    def __init__(self, synchronizer_id: _Optional[str] = ...) -> None: ...

class CountInFlightResponse(_message.Message):
    __slots__ = ("pending_submissions", "pending_transactions")
    PENDING_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    PENDING_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    pending_submissions: int
    pending_transactions: int
    def __init__(self, pending_submissions: _Optional[int] = ..., pending_transactions: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencer_initialization_snapshot_pb2 import ImplementationSpecificInfo, SequencerMemberStatus, SequencerPruningStatus, SequencerSnapshot
from .sequencer_pruning_administration_service_pb2 import PruneRequest, PruneResponse
from .sequencer_pruning_administration_service_pb2_grpc import SequencerPruningAdministrationServiceStub
from .sequencer_initialization_service_pb2 import InitializeSequencerFromGenesisStateRequest, InitializeSequencerFromGenesisStateResponse, InitializeSequencerFromGenesisStateV2Request, InitializeSequencerFromGenesisStateV2Response, InitializeSequencerFromOnboardingStateRequest, InitializeSequencerFromOnboardingStateResponse, InitializeSequencerFromOnboardingStateV2Request, InitializeSequencerFromOnboardingStateV2Response, InitializeSequencerFromPredecessorRequest, InitializeSequencerFromPredecessorResponse
from .sequencer_initialization_service_pb2_grpc import SequencerInitializationServiceStub
from .sequencer_bft_administration_service_pb2 import AddPeerEndpointRequest, AddPeerEndpointResponse, Authenticated, GetOrderingTopologyRequest, GetOrderingTopologyResponse, GetPeerNetworkStatusRequest, GetPeerNetworkStatusResponse, PeerConnectionStatus, PeerEndpoint, PeerEndpointHealth, PeerEndpointHealthStatus, PeerEndpointId, PeerEndpointStatus, PlainTextPeerEndpoint, RemovePeerEndpointRequest, RemovePeerEndpointResponse, SetPerformanceMetricsEnabledRequest, SetPerformanceMetricsEnabledResponse, TlsClientCertificate, TlsPeerEndpoint
from .sequencer_bft_administration_service_pb2_grpc import SequencerBftAdministrationServiceStub
from .sequencer_bft_pruning_administration_service_pb2 import BftOrdererPruningSchedule, BftPruneRequest, BftPruneResponse, BftPruningStatusRequest, BftPruningStatusResponse, GetBftScheduleRequest, GetBftScheduleResponse, SetBftScheduleRequest, SetBftScheduleResponse, SetMinBlocksToKeepRequest, SetMinBlocksToKeepResponse
from .sequencer_bft_pruning_administration_service_pb2_grpc import SequencerBftPruningAdministrationServiceStub
from .sequencer_administration_service_pb2 import DisableMemberRequest, DisableMemberResponse, OnboardingStateForSequencer, OnboardingStateForSequencerV2, OnboardingStateRequest, OnboardingStateResponse, OnboardingStateV2Request, OnboardingStateV2Response, PruningStatusRequest, PruningStatusResponse, SetTrafficPurchasedRequest, SetTrafficPurchasedResponse, SnapshotRequest, SnapshotResponse, TrafficControlStateRequest, TrafficControlStateResponse
from .sequencer_administration_service_pb2_grpc import SequencerAdministrationServiceStub
from .sequencer_bft_additional_snapshot_info_pb2 import BftSequencerSnapshotAdditionalInfo, BlacklistLeaderSelectionPolicyState

__all__ = [
    "AddPeerEndpointRequest",
    "AddPeerEndpointResponse",
    "Authenticated",
    "BftOrdererPruningSchedule",
    "BftPruneRequest",
    "BftPruneResponse",
    "BftPruningStatusRequest",
    "BftPruningStatusResponse",
    "BftSequencerSnapshotAdditionalInfo",
    "BlacklistLeaderSelectionPolicyState",
    "DisableMemberRequest",
    "DisableMemberResponse",
    "GetBftScheduleRequest",
    "GetBftScheduleResponse",
    "GetOrderingTopologyRequest",
    "GetOrderingTopologyResponse",
    "GetPeerNetworkStatusRequest",
    "GetPeerNetworkStatusResponse",
    "ImplementationSpecificInfo",
    "InitializeSequencerFromGenesisStateRequest",
    "InitializeSequencerFromGenesisStateResponse",
    "InitializeSequencerFromGenesisStateV2Request",
    "InitializeSequencerFromGenesisStateV2Response",
    "InitializeSequencerFromOnboardingStateRequest",
    "InitializeSequencerFromOnboardingStateResponse",
    "InitializeSequencerFromOnboardingStateV2Request",
    "InitializeSequencerFromOnboardingStateV2Response",
    "InitializeSequencerFromPredecessorRequest",
    "InitializeSequencerFromPredecessorResponse",
    "OnboardingStateForSequencer",
    "OnboardingStateForSequencerV2",
    "OnboardingStateRequest",
    "OnboardingStateResponse",
    "OnboardingStateV2Request",
    "OnboardingStateV2Response",
    "PeerConnectionStatus",
    "PeerEndpoint",
    "PeerEndpointHealth",
    "PeerEndpointHealthStatus",
    "PeerEndpointId",
    "PeerEndpointStatus",
    "PlainTextPeerEndpoint",
    "PruneRequest",
    "PruneResponse",
    "PruningStatusRequest",
    "PruningStatusResponse",
    "RemovePeerEndpointRequest",
    "RemovePeerEndpointResponse",
    "SequencerAdministrationServiceStub",
    "SequencerBftAdministrationServiceStub",
    "SequencerBftPruningAdministrationServiceStub",
    "SequencerInitializationServiceStub",
    "SequencerMemberStatus",
    "SequencerPruningAdministrationServiceStub",
    "SequencerPruningStatus",
    "SequencerSnapshot",
    "SetBftScheduleRequest",
    "SetBftScheduleResponse",
    "SetMinBlocksToKeepRequest",
    "SetMinBlocksToKeepResponse",
    "SetPerformanceMetricsEnabledRequest",
    "SetPerformanceMetricsEnabledResponse",
    "SetTrafficPurchasedRequest",
    "SetTrafficPurchasedResponse",
    "SnapshotRequest",
    "SnapshotResponse",
    "TlsClientCertificate",
    "TlsPeerEndpoint",
    "TrafficControlStateRequest",
    "TrafficControlStateResponse",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.js_status import JsStatus


T = TypeVar("T", bound="JsInterfaceView")


@_attrs_define
class JsInterfaceView:
    """View of a create event matched by an interface filter.

    Attributes:
        interface_id (str): The interface implemented by the matched event.
            The identifier uses the package-id reference format.

            Required
        view_status (JsStatus):
        view_value (Any | Unset): The value of the interface's view method on this event.
            Set if it was requested in the ``InterfaceFilter`` and it could be
            successfully computed.
            Optional
    """

    interface_id: str
    view_status: JsStatus
    view_value: Any | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        interface_id = self.interface_id

        view_status = self.view_status.to_dict()

        view_value = self.view_value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "interfaceId": interface_id,
                "viewStatus": view_status,
            }
        )
        if view_value is not UNSET:
            field_dict["viewValue"] = view_value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.js_status import JsStatus

        d = dict(src_dict)
        interface_id = d.pop("interfaceId")

        view_status = JsStatus.from_dict(d.pop("viewStatus"))

        view_value = d.pop("viewValue", UNSET)

        js_interface_view = cls(
            interface_id=interface_id,
            view_status=view_status,
            view_value=view_value,
        )

        js_interface_view.additional_properties = d
        return js_interface_view

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_manager_write_service_pb2 import AddTransactionsRequest, AddTransactionsResponse, AuthorizeRequest, AuthorizeResponse, CreateTemporaryTopologyStoreRequest, CreateTemporaryTopologyStoreResponse, DropTemporaryTopologyStoreRequest, DropTemporaryTopologyStoreResponse, GenerateTransactionsRequest, GenerateTransactionsResponse, ImportTopologySnapshotRequest, ImportTopologySnapshotResponse, ImportTopologySnapshotV2Request, ImportTopologySnapshotV2Response, SignTransactionsRequest, SignTransactionsResponse

__all__ = [
    "TopologyManagerWriteServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyManagerWriteServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyManagerWriteServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyManagerWriteServiceAsyncStub: ...  # type: ignore
    def Authorize(self, __1: AuthorizeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AuthorizeResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, AuthorizeResponse]: ...
    def AddTransactions(self, __1: AddTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddTransactionsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, AddTransactionsResponse]: ...
    def ImportTopologySnapshot(self, __1: _typing.Iterable[ImportTopologySnapshotRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportTopologySnapshotResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportTopologySnapshotResponse]: ...
    def ImportTopologySnapshotV2(self, __1: _typing.Iterable[ImportTopologySnapshotV2Request], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportTopologySnapshotV2Response | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportTopologySnapshotV2Response]: ...
    def SignTransactions(self, __1: SignTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SignTransactionsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, SignTransactionsResponse]: ...
    def GenerateTransactions(self, __1: GenerateTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateTransactionsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateTransactionsResponse]: ...
    def CreateTemporaryTopologyStore(self, __1: CreateTemporaryTopologyStoreRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CreateTemporaryTopologyStoreResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, CreateTemporaryTopologyStoreResponse]: ...
    def DropTemporaryTopologyStore(self, __1: DropTemporaryTopologyStoreRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DropTemporaryTopologyStoreResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, DropTemporaryTopologyStoreResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerWriteServiceBlockingStub(TopologyManagerWriteServiceStub):
    def Authorize(self, __1: AuthorizeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AuthorizeResponse: ...
    def AddTransactions(self, __1: AddTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddTransactionsResponse: ...
    def ImportTopologySnapshot(self, __1: _typing.Iterable[ImportTopologySnapshotRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportTopologySnapshotResponse: ...
    def ImportTopologySnapshotV2(self, __1: _typing.Iterable[ImportTopologySnapshotV2Request], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportTopologySnapshotV2Response: ...
    def SignTransactions(self, __1: SignTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SignTransactionsResponse: ...
    def GenerateTransactions(self, __1: GenerateTransactionsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateTransactionsResponse: ...
    def CreateTemporaryTopologyStore(self, __1: CreateTemporaryTopologyStoreRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CreateTemporaryTopologyStoreResponse: ...
    def DropTemporaryTopologyStore(self, __1: DropTemporaryTopologyStoreRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DropTemporaryTopologyStoreResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerWriteServiceAsyncStub(TopologyManagerWriteServiceStub):
    def Authorize(self, __1: AuthorizeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AuthorizeResponse]: ...  # type: ignore
    def AddTransactions(self, __1: AddTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AddTransactionsResponse]: ...  # type: ignore
    def ImportTopologySnapshot(self, __1: _typing.Iterable[ImportTopologySnapshotRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportTopologySnapshotResponse]: ...  # type: ignore
    def ImportTopologySnapshotV2(self, __1: _typing.Iterable[ImportTopologySnapshotV2Request], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportTopologySnapshotV2Response]: ...  # type: ignore
    def SignTransactions(self, __1: SignTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SignTransactionsResponse]: ...  # type: ignore
    def GenerateTransactions(self, __1: GenerateTransactionsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateTransactionsResponse]: ...  # type: ignore
    def CreateTemporaryTopologyStore(self, __1: CreateTemporaryTopologyStoreRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, CreateTemporaryTopologyStoreResponse]: ...  # type: ignore
    def DropTemporaryTopologyStore(self, __1: DropTemporaryTopologyStoreRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DropTemporaryTopologyStoreResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SigningKeySpec(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNING_KEY_SPEC_UNSPECIFIED: _ClassVar[SigningKeySpec]
    SIGNING_KEY_SPEC_EC_CURVE25519: _ClassVar[SigningKeySpec]
    SIGNING_KEY_SPEC_EC_P256: _ClassVar[SigningKeySpec]
    SIGNING_KEY_SPEC_EC_P384: _ClassVar[SigningKeySpec]
    SIGNING_KEY_SPEC_EC_SECP256K1: _ClassVar[SigningKeySpec]

class CryptoKeyFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CRYPTO_KEY_FORMAT_UNSPECIFIED: _ClassVar[CryptoKeyFormat]
    CRYPTO_KEY_FORMAT_DER: _ClassVar[CryptoKeyFormat]
    CRYPTO_KEY_FORMAT_RAW: _ClassVar[CryptoKeyFormat]
    CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO: _ClassVar[CryptoKeyFormat]

class SigningAlgorithmSpec(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNING_ALGORITHM_SPEC_UNSPECIFIED: _ClassVar[SigningAlgorithmSpec]
    SIGNING_ALGORITHM_SPEC_ED25519: _ClassVar[SigningAlgorithmSpec]
    SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_256: _ClassVar[SigningAlgorithmSpec]
    SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_384: _ClassVar[SigningAlgorithmSpec]

class SignatureFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNATURE_FORMAT_UNSPECIFIED: _ClassVar[SignatureFormat]
    SIGNATURE_FORMAT_RAW: _ClassVar[SignatureFormat]
    SIGNATURE_FORMAT_DER: _ClassVar[SignatureFormat]
    SIGNATURE_FORMAT_CONCAT: _ClassVar[SignatureFormat]
    SIGNATURE_FORMAT_SYMBOLIC: _ClassVar[SignatureFormat]
SIGNING_KEY_SPEC_UNSPECIFIED: SigningKeySpec
SIGNING_KEY_SPEC_EC_CURVE25519: SigningKeySpec
SIGNING_KEY_SPEC_EC_P256: SigningKeySpec
SIGNING_KEY_SPEC_EC_P384: SigningKeySpec
SIGNING_KEY_SPEC_EC_SECP256K1: SigningKeySpec
CRYPTO_KEY_FORMAT_UNSPECIFIED: CryptoKeyFormat
CRYPTO_KEY_FORMAT_DER: CryptoKeyFormat
CRYPTO_KEY_FORMAT_RAW: CryptoKeyFormat
CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO: CryptoKeyFormat
SIGNING_ALGORITHM_SPEC_UNSPECIFIED: SigningAlgorithmSpec
SIGNING_ALGORITHM_SPEC_ED25519: SigningAlgorithmSpec
SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_256: SigningAlgorithmSpec
SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_384: SigningAlgorithmSpec
SIGNATURE_FORMAT_UNSPECIFIED: SignatureFormat
SIGNATURE_FORMAT_RAW: SignatureFormat
SIGNATURE_FORMAT_DER: SignatureFormat
SIGNATURE_FORMAT_CONCAT: SignatureFormat
SIGNATURE_FORMAT_SYMBOLIC: SignatureFormat

class SigningPublicKey(_message.Message):
    __slots__ = ("format", "key_data", "key_spec")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    KEY_DATA_FIELD_NUMBER: _ClassVar[int]
    KEY_SPEC_FIELD_NUMBER: _ClassVar[int]
    format: CryptoKeyFormat
    key_data: bytes
    key_spec: SigningKeySpec
    def __init__(self, format: _Optional[_Union[CryptoKeyFormat, str]] = ..., key_data: _Optional[bytes] = ..., key_spec: _Optional[_Union[SigningKeySpec, str]] = ...) -> None: ...

class Signature(_message.Message):
    __slots__ = ("format", "signature", "signed_by", "signing_algorithm_spec")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    SIGNING_ALGORITHM_SPEC_FIELD_NUMBER: _ClassVar[int]
    format: SignatureFormat
    signature: bytes
    signed_by: str
    signing_algorithm_spec: SigningAlgorithmSpec
    def __init__(self, format: _Optional[_Union[SignatureFormat, str]] = ..., signature: _Optional[bytes] = ..., signed_by: _Optional[str] = ..., signing_algorithm_spec: _Optional[_Union[SigningAlgorithmSpec, str]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .party_management_service_pb2 import AllocatePartyRequest, AllocatePartyResponse, GetParticipantIdRequest, GetParticipantIdResponse, GetPartiesRequest, GetPartiesResponse, ListKnownPartiesRequest, ListKnownPartiesResponse, UpdatePartyDetailsRequest, UpdatePartyDetailsResponse, UpdatePartyIdentityProviderRequest, UpdatePartyIdentityProviderResponse

__all__ = [
    "PartyManagementServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PartyManagementServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PartyManagementServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PartyManagementServiceAsyncStub: ...  # type: ignore
    def GetParticipantId(self, __1: GetParticipantIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetParticipantIdResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetParticipantIdResponse]: ...
    def GetParties(self, __1: GetPartiesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPartiesResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetPartiesResponse]: ...
    def ListKnownParties(self, __1: ListKnownPartiesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListKnownPartiesResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListKnownPartiesResponse]: ...
    def AllocateParty(self, __1: AllocatePartyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AllocatePartyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, AllocatePartyResponse]: ...
    def UpdatePartyDetails(self, __1: UpdatePartyDetailsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UpdatePartyDetailsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, UpdatePartyDetailsResponse]: ...
    def UpdatePartyIdentityProviderId(self, __1: UpdatePartyIdentityProviderRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UpdatePartyIdentityProviderResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, UpdatePartyIdentityProviderResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyManagementServiceBlockingStub(PartyManagementServiceStub):
    def GetParticipantId(self, __1: GetParticipantIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetParticipantIdResponse: ...
    def GetParties(self, __1: GetPartiesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPartiesResponse: ...
    def ListKnownParties(self, __1: ListKnownPartiesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListKnownPartiesResponse: ...
    def AllocateParty(self, __1: AllocatePartyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AllocatePartyResponse: ...
    def UpdatePartyDetails(self, __1: UpdatePartyDetailsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UpdatePartyDetailsResponse: ...
    def UpdatePartyIdentityProviderId(self, __1: UpdatePartyIdentityProviderRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UpdatePartyIdentityProviderResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyManagementServiceAsyncStub(PartyManagementServiceStub):
    def GetParticipantId(self, __1: GetParticipantIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetParticipantIdResponse]: ...  # type: ignore
    def GetParties(self, __1: GetPartiesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetPartiesResponse]: ...  # type: ignore
    def ListKnownParties(self, __1: ListKnownPartiesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListKnownPartiesResponse]: ...  # type: ignore
    def AllocateParty(self, __1: AllocatePartyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AllocatePartyResponse]: ...  # type: ignore
    def UpdatePartyDetails(self, __1: UpdatePartyDetailsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UpdatePartyDetailsResponse]: ...  # type: ignore
    def UpdatePartyIdentityProviderId(self, __1: UpdatePartyIdentityProviderRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UpdatePartyIdentityProviderResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .active_contract_pb2 import ActiveContract, ActiveContractOld, Contract
from .resource_management_service_pb2 import GetResourceLimitsRequest, GetResourceLimitsResponse, ResourceLimits, SetResourceLimitsRequest, SetResourceLimitsResponse
from .resource_management_service_pb2_grpc import ResourceManagementServiceStub
from .traffic_control_service_pb2 import TrafficControlStateRequest, TrafficControlStateResponse, TrafficState
from .traffic_control_service_pb2_grpc import TrafficControlServiceStub
from .package_service_pb2 import DarDescription, GetDarContentsRequest, GetDarContentsResponse, GetDarRequest, GetDarResponse, GetPackageContentsRequest, GetPackageContentsResponse, GetPackageReferencesRequest, GetPackageReferencesResponse, ListDarsRequest, ListDarsResponse, ListPackagesRequest, ListPackagesResponse, ModuleDescription, PackageDescription, RemoveDarRequest, RemoveDarResponse, RemovePackageRequest, RemovePackageResponse, UnvetDarRequest, UnvetDarResponse, UploadDarRequest, UploadDarResponse, ValidateDarRequest, ValidateDarResponse, VetDarRequest, VetDarResponse
from .package_service_pb2_grpc import PackageServiceStub
from .participant_status_service_pb2 import ConnectedSynchronizer, ParticipantStatusRequest, ParticipantStatusResponse
from .participant_status_service_pb2_grpc import ParticipantStatusServiceStub
from .acs_import_pb2 import ContractImportMode, RepresentativePackageIdOverride
from .synchronizer_connectivity_pb2 import ConnectSynchronizerRequest, ConnectSynchronizerResponse, DisconnectAllSynchronizersRequest, DisconnectAllSynchronizersResponse, DisconnectSynchronizerRequest, DisconnectSynchronizerResponse, GetSynchronizerIdRequest, GetSynchronizerIdResponse, ListConnectedSynchronizersRequest, ListConnectedSynchronizersResponse, ListRegisteredSynchronizersRequest, ListRegisteredSynchronizersResponse, LogoutRequest, LogoutResponse, ModifySynchronizerRequest, ModifySynchronizerResponse, ReconnectSynchronizerRequest, ReconnectSynchronizerResponse, ReconnectSynchronizersRequest, ReconnectSynchronizersResponse, RegisterSynchronizerRequest, RegisterSynchronizerResponse, SynchronizerConnectionConfig
from .synchronizer_connectivity_pb2_grpc import SynchronizerConnectivityServiceStub
from .participant_repair_service_pb2 import ChangeAssignationRequest, ChangeAssignationResponse, ExportAcsOldRequest, ExportAcsOldResponse, ExportAcsRequest, ExportAcsResponse, ExportAcsTargetSynchronizer, IgnoreEventsRequest, IgnoreEventsResponse, ImportAcsOldRequest, ImportAcsOldResponse, ImportAcsRequest, ImportAcsResponse, MigrateSynchronizerRequest, MigrateSynchronizerResponse, PurgeContractsRequest, PurgeContractsResponse, PurgeDeactivatedSynchronizerRequest, PurgeDeactivatedSynchronizerResponse, RepairCommitmentsStatus, RepairCommitmentsUsingAcsRequest, RepairCommitmentsUsingAcsResponse, RollbackUnassignmentRequest, RollbackUnassignmentResponse, UnignoreEventsRequest, UnignoreEventsResponse
from .participant_repair_service_pb2_grpc import ParticipantRepairServiceStub
from .ping_pong_service_pb2 import PingFailure, PingRequest, PingResponse, PingSuccess
from .ping_pong_service_pb2_grpc import PingServiceStub
from .party_management_service_pb2 import AddPartyAsyncRequest, AddPartyAsyncResponse, ClearPartyOnboardingFlagRequest, ClearPartyOnboardingFlagResponse, ExportPartyAcsRequest, ExportPartyAcsResponse, GetAddPartyStatusRequest, GetAddPartyStatusResponse, GetHighestOffsetByTimestampRequest, GetHighestOffsetByTimestampResponse, ImportPartyAcsRequest, ImportPartyAcsResponse, ParticipantPermission
from .party_management_service_pb2_grpc import PartyManagementServiceStub
from .pruning_service_pb2 import GetSafePruningOffsetRequest, GetSafePruningOffsetResponse, PruneRequest, PruneResponse
from .pruning_service_pb2_grpc import PruningServiceStub
from .enterprise_participant_replication_service_pb2 import SetPassiveRequest, SetPassiveResponse
from .enterprise_participant_replication_service_pb2_grpc import EnterpriseParticipantReplicationServiceStub
from .participant_inspection_service_pb2 import CommitmentContract, CommitmentContractMeta, ContractState, CountInFlightRequest, CountInFlightResponse, CounterParticipantInfo, GetConfigForSlowCounterParticipantsRequest, GetConfigForSlowCounterParticipantsResponse, GetIntervalsBehindForCounterParticipantsRequest, GetIntervalsBehindForCounterParticipantsResponse, InspectCommitmentContractsRequest, InspectCommitmentContractsResponse, Interval, LookupOffsetByTimeRequest, LookupOffsetByTimeResponse, LookupReceivedAcsCommitmentsRequest, LookupReceivedAcsCommitmentsResponse, LookupSentAcsCommitmentsRequest, LookupSentAcsCommitmentsResponse, OpenCommitmentRequest, OpenCommitmentResponse, ReceivedAcsCommitment, ReceivedAcsCommitmentPerSynchronizer, ReceivedCommitmentState, SentAcsCommitment, SentAcsCommitmentPerSynchronizer, SentCommitmentState, SetConfigForSlowCounterParticipantsRequest, SetConfigForSlowCounterParticipantsResponse, SlowCounterParticipantSynchronizerConfig, SynchronizerTimeRange, TimeRange
from .participant_inspection_service_pb2_grpc import ParticipantInspectionServiceStub
from .reassignment_id_pb2 import ReassignmentId

__all__ = [
    "ActiveContract",
    "ActiveContractOld",
    "AddPartyAsyncRequest",
    "AddPartyAsyncResponse",
    "ChangeAssignationRequest",
    "ChangeAssignationResponse",
    "ClearPartyOnboardingFlagRequest",
    "ClearPartyOnboardingFlagResponse",
    "CommitmentContract",
    "CommitmentContractMeta",
    "ConnectSynchronizerRequest",
    "ConnectSynchronizerResponse",
    "ConnectedSynchronizer",
    "Contract",
    "ContractImportMode",
    "ContractState",
    "CountInFlightRequest",
    "CountInFlightResponse",
    "CounterParticipantInfo",
    "DarDescription",
    "DisconnectAllSynchronizersRequest",
    "DisconnectAllSynchronizersResponse",
    "DisconnectSynchronizerRequest",
    "DisconnectSynchronizerResponse",
    "EnterpriseParticipantReplicationServiceStub",
    "ExportAcsOldRequest",
    "ExportAcsOldResponse",
    "ExportAcsRequest",
    "ExportAcsResponse",
    "ExportAcsTargetSynchronizer",
    "ExportPartyAcsRequest",
    "ExportPartyAcsResponse",
    "GetAddPartyStatusRequest",
    "GetAddPartyStatusResponse",
    "GetConfigForSlowCounterParticipantsRequest",
    "GetConfigForSlowCounterParticipantsResponse",
    "GetDarContentsRequest",
    "GetDarContentsResponse",
    "GetDarRequest",
    "GetDarResponse",
    "GetHighestOffsetByTimestampRequest",
    "GetHighestOffsetByTimestampResponse",
    "GetIntervalsBehindForCounterParticipantsRequest",
    "GetIntervalsBehindForCounterParticipantsResponse",
    "GetPackageContentsRequest",
    "GetPackageContentsResponse",
    "GetPackageReferencesRequest",
    "GetPackageReferencesResponse",
    "GetResourceLimitsRequest",
    "GetResourceLimitsResponse",
    "GetSafePruningOffsetRequest",
    "GetSafePruningOffsetResponse",
    "GetSynchronizerIdRequest",
    "GetSynchronizerIdResponse",
    "IgnoreEventsRequest",
    "IgnoreEventsResponse",
    "ImportAcsOldRequest",
    "ImportAcsOldResponse",
    "ImportAcsRequest",
    "ImportAcsResponse",
    "ImportPartyAcsRequest",
    "ImportPartyAcsResponse",
    "InspectCommitmentContractsRequest",
    "InspectCommitmentContractsResponse",
    "Interval",
    "ListConnectedSynchronizersRequest",
    "ListConnectedSynchronizersResponse",
    "ListDarsRequest",
    "ListDarsResponse",
    "ListPackagesRequest",
    "ListPackagesResponse",
    "ListRegisteredSynchronizersRequest",
    "ListRegisteredSynchronizersResponse",
    "LogoutRequest",
    "LogoutResponse",
    "LookupOffsetByTimeRequest",
    "LookupOffsetByTimeResponse",
    "LookupReceivedAcsCommitmentsRequest",
    "LookupReceivedAcsCommitmentsResponse",
    "LookupSentAcsCommitmentsRequest",
    "LookupSentAcsCommitmentsResponse",
    "MigrateSynchronizerRequest",
    "MigrateSynchronizerResponse",
    "ModifySynchronizerRequest",
    "ModifySynchronizerResponse",
    "ModuleDescription",
    "OpenCommitmentRequest",
    "OpenCommitmentResponse",
    "PackageDescription",
    "PackageServiceStub",
    "ParticipantInspectionServiceStub",
    "ParticipantPermission",
    "ParticipantRepairServiceStub",
    "ParticipantStatusRequest",
    "ParticipantStatusResponse",
    "ParticipantStatusServiceStub",
    "PartyManagementServiceStub",
    "PingFailure",
    "PingRequest",
    "PingResponse",
    "PingServiceStub",
    "PingSuccess",
    "PruneRequest",
    "PruneResponse",
    "PruningServiceStub",
    "PurgeContractsRequest",
    "PurgeContractsResponse",
    "PurgeDeactivatedSynchronizerRequest",
    "PurgeDeactivatedSynchronizerResponse",
    "ReassignmentId",
    "ReceivedAcsCommitment",
    "ReceivedAcsCommitmentPerSynchronizer",
    "ReceivedCommitmentState",
    "ReconnectSynchronizerRequest",
    "ReconnectSynchronizerResponse",
    "ReconnectSynchronizersRequest",
    "ReconnectSynchronizersResponse",
    "RegisterSynchronizerRequest",
    "RegisterSynchronizerResponse",
    "RemoveDarRequest",
    "RemoveDarResponse",
    "RemovePackageRequest",
    "RemovePackageResponse",
    "RepairCommitmentsStatus",
    "RepairCommitmentsUsingAcsRequest",
    "RepairCommitmentsUsingAcsResponse",
    "RepresentativePackageIdOverride",
    "ResourceLimits",
    "ResourceManagementServiceStub",
    "RollbackUnassignmentRequest",
    "RollbackUnassignmentResponse",
    "SentAcsCommitment",
    "SentAcsCommitmentPerSynchronizer",
    "SentCommitmentState",
    "SetConfigForSlowCounterParticipantsRequest",
    "SetConfigForSlowCounterParticipantsResponse",
    "SetPassiveRequest",
    "SetPassiveResponse",
    "SetResourceLimitsRequest",
    "SetResourceLimitsResponse",
    "SlowCounterParticipantSynchronizerConfig",
    "SynchronizerConnectionConfig",
    "SynchronizerConnectivityServiceStub",
    "SynchronizerTimeRange",
    "TimeRange",
    "TrafficControlServiceStub",
    "TrafficControlStateRequest",
    "TrafficControlStateResponse",
    "TrafficState",
    "UnignoreEventsRequest",
    "UnignoreEventsResponse",
    "UnvetDarRequest",
    "UnvetDarResponse",
    "UploadDarRequest",
    "UploadDarResponse",
    "ValidateDarRequest",
    "ValidateDarResponse",
    "VetDarRequest",
    "VetDarResponse",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from . import event_pb2 as _event_pb2
from . import trace_context_pb2 as _trace_context_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Transaction(_message.Message):
    __slots__ = ("update_id", "command_id", "workflow_id", "effective_at", "events", "offset", "synchronizer_id", "trace_context", "record_time", "external_transaction_hash")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    EFFECTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    command_id: str
    workflow_id: str
    effective_at: _timestamp_pb2.Timestamp
    events: _containers.RepeatedCompositeFieldContainer[_event_pb2.Event]
    offset: int
    synchronizer_id: str
    trace_context: _trace_context_pb2.TraceContext
    record_time: _timestamp_pb2.Timestamp
    external_transaction_hash: bytes
    def __init__(self, update_id: _Optional[str] = ..., command_id: _Optional[str] = ..., workflow_id: _Optional[str] = ..., effective_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., events: _Optional[_Iterable[_Union[_event_pb2.Event, _Mapping]]] = ..., offset: _Optional[int] = ..., synchronizer_id: _Optional[str] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ..., record_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., external_transaction_hash: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from enum import Enum


class JsPrepareSubmissionResponseHashingSchemeVersion(str, Enum):
    HASHING_SCHEME_VERSION_UNSPECIFIED = "HASHING_SCHEME_VERSION_UNSPECIFIED"
    HASHING_SCHEME_VERSION_V2 = "HASHING_SCHEME_VERSION_V2"

    def __str__(self) -> str:
        return str(self.value)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddPeerEndpointRequest(_message.Message):
    __slots__ = ("endpoint",)
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    endpoint: PeerEndpoint
    def __init__(self, endpoint: _Optional[_Union[PeerEndpoint, _Mapping]] = ...) -> None: ...

class RemovePeerEndpointRequest(_message.Message):
    __slots__ = ("endpoint_id",)
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    endpoint_id: PeerEndpointId
    def __init__(self, endpoint_id: _Optional[_Union[PeerEndpointId, _Mapping]] = ...) -> None: ...

class PeerEndpoint(_message.Message):
    __slots__ = ("address", "port", "plain_text", "tls")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    PLAIN_TEXT_FIELD_NUMBER: _ClassVar[int]
    TLS_FIELD_NUMBER: _ClassVar[int]
    address: str
    port: int
    plain_text: PlainTextPeerEndpoint
    tls: TlsPeerEndpoint
    def __init__(self, address: _Optional[str] = ..., port: _Optional[int] = ..., plain_text: _Optional[_Union[PlainTextPeerEndpoint, _Mapping]] = ..., tls: _Optional[_Union[TlsPeerEndpoint, _Mapping]] = ...) -> None: ...

class PeerEndpointId(_message.Message):
    __slots__ = ("address", "port", "tls")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    TLS_FIELD_NUMBER: _ClassVar[int]
    address: str
    port: int
    tls: bool
    def __init__(self, address: _Optional[str] = ..., port: _Optional[int] = ..., tls: bool = ...) -> None: ...

class PlainTextPeerEndpoint(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TlsPeerEndpoint(_message.Message):
    __slots__ = ("custom_server_trust_certificate", "client_certificate")
    CUSTOM_SERVER_TRUST_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    custom_server_trust_certificate: bytes
    client_certificate: TlsClientCertificate
    def __init__(self, custom_server_trust_certificate: _Optional[bytes] = ..., client_certificate: _Optional[_Union[TlsClientCertificate, _Mapping]] = ...) -> None: ...

class TlsClientCertificate(_message.Message):
    __slots__ = ("certificate_chain", "private_key_file")
    CERTIFICATE_CHAIN_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FILE_FIELD_NUMBER: _ClassVar[int]
    certificate_chain: bytes
    private_key_file: str
    def __init__(self, certificate_chain: _Optional[bytes] = ..., private_key_file: _Optional[str] = ...) -> None: ...

class AddPeerEndpointResponse(_message.Message):
    __slots__ = ("added",)
    ADDED_FIELD_NUMBER: _ClassVar[int]
    added: bool
    def __init__(self, added: bool = ...) -> None: ...

class RemovePeerEndpointResponse(_message.Message):
    __slots__ = ("removed",)
    REMOVED_FIELD_NUMBER: _ClassVar[int]
    removed: bool
    def __init__(self, removed: bool = ...) -> None: ...

class Authenticated(_message.Message):
    __slots__ = ("sequencer_id",)
    SEQUENCER_ID_FIELD_NUMBER: _ClassVar[int]
    sequencer_id: str
    def __init__(self, sequencer_id: _Optional[str] = ...) -> None: ...

class PeerEndpointHealthStatus(_message.Message):
    __slots__ = ("unknown_endpoint", "disconnected", "unauthenticated", "authenticated")
    class UnknownEndpoint(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Disconnected(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Unauthenticated(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    UNKNOWN_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    DISCONNECTED_FIELD_NUMBER: _ClassVar[int]
    UNAUTHENTICATED_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATED_FIELD_NUMBER: _ClassVar[int]
    unknown_endpoint: PeerEndpointHealthStatus.UnknownEndpoint
    disconnected: PeerEndpointHealthStatus.Disconnected
    unauthenticated: PeerEndpointHealthStatus.Unauthenticated
    authenticated: Authenticated
    def __init__(self, unknown_endpoint: _Optional[_Union[PeerEndpointHealthStatus.UnknownEndpoint, _Mapping]] = ..., disconnected: _Optional[_Union[PeerEndpointHealthStatus.Disconnected, _Mapping]] = ..., unauthenticated: _Optional[_Union[PeerEndpointHealthStatus.Unauthenticated, _Mapping]] = ..., authenticated: _Optional[_Union[Authenticated, _Mapping]] = ...) -> None: ...

class PeerEndpointHealth(_message.Message):
    __slots__ = ("status", "description")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    status: PeerEndpointHealthStatus
    description: str
    def __init__(self, status: _Optional[_Union[PeerEndpointHealthStatus, _Mapping]] = ..., description: _Optional[str] = ...) -> None: ...

class PeerEndpointStatus(_message.Message):
    __slots__ = ("endpoint_id", "is_outgoing_connection", "health")
    ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    IS_OUTGOING_CONNECTION_FIELD_NUMBER: _ClassVar[int]
    HEALTH_FIELD_NUMBER: _ClassVar[int]
    endpoint_id: PeerEndpointId
    is_outgoing_connection: bool
    health: PeerEndpointHealth
    def __init__(self, endpoint_id: _Optional[_Union[PeerEndpointId, _Mapping]] = ..., is_outgoing_connection: bool = ..., health: _Optional[_Union[PeerEndpointHealth, _Mapping]] = ...) -> None: ...

class PeerConnectionStatus(_message.Message):
    __slots__ = ("peer_endpoint_status", "peer_incoming_connection")
    PEER_ENDPOINT_STATUS_FIELD_NUMBER: _ClassVar[int]
    PEER_INCOMING_CONNECTION_FIELD_NUMBER: _ClassVar[int]
    peer_endpoint_status: PeerEndpointStatus
    peer_incoming_connection: Authenticated
    def __init__(self, peer_endpoint_status: _Optional[_Union[PeerEndpointStatus, _Mapping]] = ..., peer_incoming_connection: _Optional[_Union[Authenticated, _Mapping]] = ...) -> None: ...

class GetPeerNetworkStatusRequest(_message.Message):
    __slots__ = ("endpoint_ids",)
    ENDPOINT_IDS_FIELD_NUMBER: _ClassVar[int]
    endpoint_ids: _containers.RepeatedCompositeFieldContainer[PeerEndpointId]
    def __init__(self, endpoint_ids: _Optional[_Iterable[_Union[PeerEndpointId, _Mapping]]] = ...) -> None: ...

class GetPeerNetworkStatusResponse(_message.Message):
    __slots__ = ("statuses",)
    STATUSES_FIELD_NUMBER: _ClassVar[int]
    statuses: _containers.RepeatedCompositeFieldContainer[PeerConnectionStatus]
    def __init__(self, statuses: _Optional[_Iterable[_Union[PeerConnectionStatus, _Mapping]]] = ...) -> None: ...

class GetOrderingTopologyRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetOrderingTopologyResponse(_message.Message):
    __slots__ = ("current_epoch", "sequencer_ids")
    CURRENT_EPOCH_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_IDS_FIELD_NUMBER: _ClassVar[int]
    current_epoch: int
    sequencer_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, current_epoch: _Optional[int] = ..., sequencer_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class SetPerformanceMetricsEnabledRequest(_message.Message):
    __slots__ = ("enabled",)
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    def __init__(self, enabled: bool = ...) -> None: ...

class SetPerformanceMetricsEnabledResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import acs_import_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_acs__import__pb2
from . import synchronizer_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/admin/participant/v30/participant_repair_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a>com/digitalasset/canton/admin/participant/v30/acs_import.proto\x1aMcom/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x15PurgeContractsRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12!\n\x0c\x63ontract_ids\x18\x02 \x03(\tR\x0b\x63ontractIds\x12\x32\n\x15ignore_already_purged\x18\x03 \x01(\x08R\x13ignoreAlreadyPurged\"\x18\n\x16PurgeContractsResponse\"\xaf\x03\n\x18\x43hangeAssignationRequest\x12:\n\x19source_synchronizer_alias\x18\x01 \x01(\tR\x17sourceSynchronizerAlias\x12:\n\x19target_synchronizer_alias\x18\x02 \x01(\tR\x17targetSynchronizerAlias\x12#\n\rskip_inactive\x18\x03 \x01(\x08R\x0cskipInactive\x12n\n\tcontracts\x18\x04 \x03(\x0b\x32P.com.digitalasset.canton.admin.participant.v30.ChangeAssignationRequest.ContractR\tcontracts\x1a\x85\x01\n\x08\x43ontract\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12G\n\x1dreassignment_counter_override\x18\x02 \x01(\x03H\x00R\x1breassignmentCounterOverride\x88\x01\x01\x42 \n\x1e_reassignment_counter_override\"\x1b\n\x19\x43hangeAssignationResponse\"\x8f\x02\n\x1aMigrateSynchronizerRequest\x12:\n\x19source_synchronizer_alias\x18\x01 \x01(\tR\x17sourceSynchronizerAlias\x12\x9e\x01\n%target_synchronizer_connection_config\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\"targetSynchronizerConnectionConfig\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x1d\n\x1bMigrateSynchronizerResponse\"\xf0\x01\n\x13\x45xportAcsOldRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x14\n\x05\x66orce\x18\x05 \x01(\x08R\x05\x66orce\x12/\n\x13parties_offboarding\x18\x06 \x01(\x08R\x12partiesOffboarding:\x02\x18\x01J\x04\x08\x04\x10\x05\"0\n\x14\x45xportAcsOldResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk:\x02\x18\x01\"\xba\x01\n\x13ImportAcsOldRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12R\n&allow_contract_id_suffix_recomputation\x18\x03 \x01(\x08R\"allowContractIdSuffixRecomputation\"\xe9\x01\n\x14ImportAcsOldResponse\x12\x8a\x01\n\x13\x63ontract_id_mapping\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.admin.participant.v30.ImportAcsOldResponse.ContractIdMappingEntryR\x11\x63ontractIdMapping\x1a\x44\n\x16\x43ontractIdMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"S\n\x1b\x45xportAcsTargetSynchronizer\x12\x34\n\x16target_synchronizer_id\x18\x01 \x01(\tR\x14targetSynchronizerId\"\xfb\x03\n\x10\x45xportAcsRequest\x12\x1b\n\tparty_ids\x18\x01 \x03(\tR\x08partyIds\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12#\n\rledger_offset\x18\x03 \x01(\x03R\x0cledgerOffset\x12\xa4\x01\n\x1d\x63ontract_synchronizer_renames\x18\x04 \x03(\x0b\x32`.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest.ContractSynchronizerRenamesEntryR\x1b\x63ontractSynchronizerRenames\x12\x38\n\x18\x65xcluded_stakeholder_ids\x18\x05 \x03(\tR\x16\x65xcludedStakeholderIds\x1a\x9a\x01\n ContractSynchronizerRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12`\n\x05value\x18\x02 \x01(\x0b\x32J.com.digitalasset.canton.admin.participant.v30.ExportAcsTargetSynchronizerR\x05value:\x02\x38\x01\")\n\x11\x45xportAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xb0\x03\n\x10ImportAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12s\n\x14\x63ontract_import_mode\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.admin.participant.v30.ContractImportModeR\x12\x63ontractImportMode\x12\x38\n\x18\x65xcluded_stakeholder_ids\x18\x04 \x03(\tR\x16\x65xcludedStakeholderIds\x12\x9b\x01\n\"representative_package_id_override\x18\x05 \x01(\x0b\x32N.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverrideR\x1frepresentativePackageIdOverride\"\xe7\x01\n\x11ImportAcsResponse\x12\x8a\x01\n\x14\x63ontract_id_mappings\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse.ContractIdMappingsEntryR\x12\x63ontractIdMappings\x1a\x45\n\x17\x43ontractIdMappingsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"T\n#PurgeDeactivatedSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"&\n$PurgeDeactivatedSynchronizerResponse\"\xaf\x01\n\x13IgnoreEventsRequest\x12\x38\n\x18physical_synchronizer_id\x18\x01 \x01(\tR\x16physicalSynchronizerId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14IgnoreEventsResponse\"\xb1\x01\n\x15UnignoreEventsRequest\x12\x38\n\x18physical_synchronizer_id\x18\x01 \x01(\tR\x16physicalSynchronizerId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x18\n\x16UnignoreEventsResponse\"\xb2\x01\n\x1bRollbackUnassignmentRequest\x12\'\n\x0freassignment_id\x18\x01 \x01(\tR\x0ereassignmentId\x12\x34\n\x16source_synchronizer_id\x18\x02 \x01(\tR\x14sourceSynchronizerId\x12\x34\n\x16target_synchronizer_id\x18\x03 \x01(\tR\x14targetSynchronizerId\"\x1e\n\x1cRollbackUnassignmentResponse\"\xe6\x01\n RepairCommitmentsUsingAcsRequest\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\x12\x36\n\x17\x63ounter_participant_ids\x18\x02 \x03(\tR\x15\x63ounterParticipantIds\x12\x1b\n\tparty_ids\x18\x03 \x03(\tR\x08partyIds\x12\x42\n\x0ftimeout_seconds\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0etimeoutSeconds\"\x87\x01\n!RepairCommitmentsUsingAcsResponse\x12\x62\n\x08statuses\x18\x01 \x03(\x0b\x32\x46.com.digitalasset.canton.admin.participant.v30.RepairCommitmentsStatusR\x08statuses\"\xcf\x01\n\x17RepairCommitmentsStatus\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12%\n\rerror_message\x18\x02 \x01(\tH\x00R\x0c\x65rrorMessage\x12Z\n\x1a\x63ompleted_repair_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x18\x63ompletedRepairTimestampB\x08\n\x06status2\xec\x0f\n\x18ParticipantRepairService\x12\x9e\x01\n\x0c\x45xportAcsOld\x12\x42.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ExportAcsOldResponse\"\x03\x88\x02\x01\x30\x01\x12\x99\x01\n\x0cImportAcsOld\x12\x42.com.digitalasset.canton.admin.participant.v30.ImportAcsOldRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ImportAcsOldResponse(\x01\x12\x90\x01\n\tExportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ExportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ExportAcsResponse0\x01\x12\x90\x01\n\tImportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ImportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse(\x01\x12\x9d\x01\n\x0ePurgeContracts\x12\x44.com.digitalasset.canton.admin.participant.v30.PurgeContractsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.PurgeContractsResponse\x12\xac\x01\n\x13MigrateSynchronizer\x12I.com.digitalasset.canton.admin.participant.v30.MigrateSynchronizerRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.MigrateSynchronizerResponse\x12\xa6\x01\n\x11\x43hangeAssignation\x12G.com.digitalasset.canton.admin.participant.v30.ChangeAssignationRequest\x1aH.com.digitalasset.canton.admin.participant.v30.ChangeAssignationResponse\x12\xc7\x01\n\x1cPurgeDeactivatedSynchronizer\x12R.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedSynchronizerRequest\x1aS.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedSynchronizerResponse\x12\x97\x01\n\x0cIgnoreEvents\x12\x42.com.digitalasset.canton.admin.participant.v30.IgnoreEventsRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.IgnoreEventsResponse\x12\x9d\x01\n\x0eUnignoreEvents\x12\x44.com.digitalasset.canton.admin.participant.v30.UnignoreEventsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.UnignoreEventsResponse\x12\xaf\x01\n\x14RollbackUnassignment\x12J.com.digitalasset.canton.admin.participant.v30.RollbackUnassignmentRequest\x1aK.com.digitalasset.canton.admin.participant.v30.RollbackUnassignmentResponse\x12\xbe\x01\n\x19RepairCommitmentsUsingAcs\x12O.com.digitalasset.canton.admin.participant.v30.RepairCommitmentsUsingAcsRequest\x1aP.com.digitalasset.canton.admin.participant.v30.RepairCommitmentsUsingAcsResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_repair_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSOLDREQUEST']._loaded_options = None
  _globals['_EXPORTACSOLDREQUEST']._serialized_options = b'\030\001'
  _globals['_EXPORTACSOLDRESPONSE']._loaded_options = None
  _globals['_EXPORTACSOLDRESPONSE']._serialized_options = b'\030\001'
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._loaded_options = None
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._loaded_options = None
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_PARTICIPANTREPAIRSERVICE'].methods_by_name['ExportAcsOld']._loaded_options = None
  _globals['_PARTICIPANTREPAIRSERVICE'].methods_by_name['ExportAcsOld']._serialized_options = b'\210\002\001'
  _globals['_PURGECONTRACTSREQUEST']._serialized_start=338
  _globals['_PURGECONTRACTSREQUEST']._serialized_end=495
  _globals['_PURGECONTRACTSRESPONSE']._serialized_start=497
  _globals['_PURGECONTRACTSRESPONSE']._serialized_end=521
  _globals['_CHANGEASSIGNATIONREQUEST']._serialized_start=524
  _globals['_CHANGEASSIGNATIONREQUEST']._serialized_end=955
  _globals['_CHANGEASSIGNATIONREQUEST_CONTRACT']._serialized_start=822
  _globals['_CHANGEASSIGNATIONREQUEST_CONTRACT']._serialized_end=955
  _globals['_CHANGEASSIGNATIONRESPONSE']._serialized_start=957
  _globals['_CHANGEASSIGNATIONRESPONSE']._serialized_end=984
  _globals['_MIGRATESYNCHRONIZERREQUEST']._serialized_start=987
  _globals['_MIGRATESYNCHRONIZERREQUEST']._serialized_end=1258
  _globals['_MIGRATESYNCHRONIZERRESPONSE']._serialized_start=1260
  _globals['_MIGRATESYNCHRONIZERRESPONSE']._serialized_end=1289
  _globals['_EXPORTACSOLDREQUEST']._serialized_start=1292
  _globals['_EXPORTACSOLDREQUEST']._serialized_end=1532
  _globals['_EXPORTACSOLDRESPONSE']._serialized_start=1534
  _globals['_EXPORTACSOLDRESPONSE']._serialized_end=1582
  _globals['_IMPORTACSOLDREQUEST']._serialized_start=1585
  _globals['_IMPORTACSOLDREQUEST']._serialized_end=1771
  _globals['_IMPORTACSOLDRESPONSE']._serialized_start=1774
  _globals['_IMPORTACSOLDRESPONSE']._serialized_end=2007
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_start=1939
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_end=2007
  _globals['_EXPORTACSTARGETSYNCHRONIZER']._serialized_start=2009
  _globals['_EXPORTACSTARGETSYNCHRONIZER']._serialized_end=2092
  _globals['_EXPORTACSREQUEST']._serialized_start=2095
  _globals['_EXPORTACSREQUEST']._serialized_end=2602
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_start=2448
  _globals['_EXPORTACSREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_end=2602
  _globals['_EXPORTACSRESPONSE']._serialized_start=2604
  _globals['_EXPORTACSRESPONSE']._serialized_end=2645
  _globals['_IMPORTACSREQUEST']._serialized_start=2648
  _globals['_IMPORTACSREQUEST']._serialized_end=3080
  _globals['_IMPORTACSRESPONSE']._serialized_start=3083
  _globals['_IMPORTACSRESPONSE']._serialized_end=3314
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_start=3245
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_end=3314
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERREQUEST']._serialized_start=3316
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERREQUEST']._serialized_end=3400
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERRESPONSE']._serialized_start=3402
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERRESPONSE']._serialized_end=3440
  _globals['_IGNOREEVENTSREQUEST']._serialized_start=3443
  _globals['_IGNOREEVENTSREQUEST']._serialized_end=3618
  _globals['_IGNOREEVENTSRESPONSE']._serialized_start=3620
  _globals['_IGNOREEVENTSRESPONSE']._serialized_end=3642
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_start=3645
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_end=3822
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_start=3824
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_end=3848
  _globals['_ROLLBACKUNASSIGNMENTREQUEST']._serialized_start=3851
  _globals['_ROLLBACKUNASSIGNMENTREQUEST']._serialized_end=4029
  _globals['_ROLLBACKUNASSIGNMENTRESPONSE']._serialized_start=4031
  _globals['_ROLLBACKUNASSIGNMENTRESPONSE']._serialized_end=4061
  _globals['_REPAIRCOMMITMENTSUSINGACSREQUEST']._serialized_start=4064
  _globals['_REPAIRCOMMITMENTSUSINGACSREQUEST']._serialized_end=4294
  _globals['_REPAIRCOMMITMENTSUSINGACSRESPONSE']._serialized_start=4297
  _globals['_REPAIRCOMMITMENTSUSINGACSRESPONSE']._serialized_end=4432
  _globals['_REPAIRCOMMITMENTSSTATUS']._serialized_start=4435
  _globals['_REPAIRCOMMITMENTSSTATUS']._serialized_end=4642
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_start=4645
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_end=6673
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetScheduleRequest(_message.Message):
    __slots__ = ("schedule",)
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    schedule: PruningSchedule
    def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ...) -> None: ...

class SetScheduleResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetScheduleRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetScheduleResponse(_message.Message):
    __slots__ = ("schedule",)
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    schedule: PruningSchedule
    def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ...) -> None: ...

class SetParticipantScheduleRequest(_message.Message):
    __slots__ = ("schedule",)
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    schedule: ParticipantPruningSchedule
    def __init__(self, schedule: _Optional[_Union[ParticipantPruningSchedule, _Mapping]] = ...) -> None: ...

class SetParticipantScheduleResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetParticipantScheduleRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetParticipantScheduleResponse(_message.Message):
    __slots__ = ("schedule",)
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    schedule: ParticipantPruningSchedule
    def __init__(self, schedule: _Optional[_Union[ParticipantPruningSchedule, _Mapping]] = ...) -> None: ...

class PruningSchedule(_message.Message):
    __slots__ = ("cron", "max_duration", "retention")
    CRON_FIELD_NUMBER: _ClassVar[int]
    MAX_DURATION_FIELD_NUMBER: _ClassVar[int]
    RETENTION_FIELD_NUMBER: _ClassVar[int]
    cron: str
    max_duration: _duration_pb2.Duration
    retention: _duration_pb2.Duration
    def __init__(self, cron: _Optional[str] = ..., max_duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., retention: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ParticipantPruningSchedule(_message.Message):
    __slots__ = ("schedule", "prune_internally_only")
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    PRUNE_INTERNALLY_ONLY_FIELD_NUMBER: _ClassVar[int]
    schedule: PruningSchedule
    prune_internally_only: bool
    def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ..., prune_internally_only: bool = ...) -> None: ...

class ClearScheduleRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ClearScheduleResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetCronRequest(_message.Message):
    __slots__ = ("cron",)
    CRON_FIELD_NUMBER: _ClassVar[int]
    cron: str
    def __init__(self, cron: _Optional[str] = ...) -> None: ...

class SetCronResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetMaxDurationRequest(_message.Message):
    __slots__ = ("max_duration",)
    MAX_DURATION_FIELD_NUMBER: _ClassVar[int]
    max_duration: _duration_pb2.Duration
    def __init__(self, max_duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class SetMaxDurationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetRetentionRequest(_message.Message):
    __slots__ = ("retention",)
    RETENTION_FIELD_NUMBER: _ClassVar[int]
    retention: _duration_pb2.Duration
    def __init__(self, retention: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class SetRetentionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FindPruningTimestampRequest(_message.Message):
    __slots__ = ("index",)
    INDEX_FIELD_NUMBER: _ClassVar[int]
    index: int
    def __init__(self, index: _Optional[int] = ...) -> None: ...

class FindPruningTimestampResponse(_message.Message):
    __slots__ = ("timestamp",)
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SetNoWaitCommitmentsFromRequest(_message.Message):
    __slots__ = ("counter_participant_ids", "synchronizer_ids")
    COUNTER_PARTICIPANT_IDS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    counter_participant_ids: _containers.RepeatedScalarFieldContainer[str]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, counter_participant_ids: _Optional[_Iterable[str]] = ..., synchronizer_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class SetNoWaitCommitmentsFromResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ResetNoWaitCommitmentsFromRequest(_message.Message):
    __slots__ = ("counter_participant_ids", "synchronizer_ids")
    COUNTER_PARTICIPANT_IDS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    counter_participant_ids: _containers.RepeatedScalarFieldContainer[str]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, counter_participant_ids: _Optional[_Iterable[str]] = ..., synchronizer_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ResetNoWaitCommitmentsFromResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Synchronizers(_message.Message):
    __slots__ = ("synchronizer_ids",)
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetNoWaitCommitmentsFromRequest(_message.Message):
    __slots__ = ("synchronizer_ids", "participant_uids")
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    participant_uids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer_ids: _Optional[_Iterable[str]] = ..., participant_uids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetNoWaitCommitmentsFromResponse(_message.Message):
    __slots__ = ("ignored_participants", "not_ignored_participants")
    IGNORED_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    NOT_IGNORED_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    ignored_participants: _containers.RepeatedCompositeFieldContainer[WaitCommitmentsSetup]
    not_ignored_participants: _containers.RepeatedCompositeFieldContainer[WaitCommitmentsSetup]
    def __init__(self, ignored_participants: _Optional[_Iterable[_Union[WaitCommitmentsSetup, _Mapping]]] = ..., not_ignored_participants: _Optional[_Iterable[_Union[WaitCommitmentsSetup, _Mapping]]] = ...) -> None: ...

class WaitCommitmentsSetup(_message.Message):
    __slots__ = ("counter_participant_uid", "synchronizers")
    COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZERS_FIELD_NUMBER: _ClassVar[int]
    counter_participant_uid: str
    synchronizers: Synchronizers
    def __init__(self, counter_participant_uid: _Optional[str] = ..., synchronizers: _Optional[_Union[Synchronizers, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="VettedPackagesRef")


@_attrs_define
class VettedPackagesRef:
    """A reference to identify one or more packages.

    A reference matches a package if its ``package_id`` matches the package's ID,
    its ``package_name`` matches the package's name, and its ``package_version``
    matches the package's version. If an attribute in the reference is left
    unspecified (i.e. as an empty string), that attribute is treated as a
    wildcard. At a minimum, ``package_id`` or the ``package_name`` must be
    specified.

    If a reference does not match any package, the reference is considered
    unresolved and the entire update request is rejected.

        Attributes:
            package_id (str): Package's package id must be the same as this field.
                Optional
            package_name (str): Package's name must be the same as this field.
                Optional
            package_version (str): Package's version must be the same as this field.
                Optional
    """

    package_id: str
    package_name: str
    package_version: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        package_id = self.package_id

        package_name = self.package_name

        package_version = self.package_version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "packageId": package_id,
                "packageName": package_name,
                "packageVersion": package_version,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        package_id = d.pop("packageId")

        package_name = d.pop("packageName")

        package_version = d.pop("packageVersion")

        vetted_packages_ref = cls(
            package_id=package_id,
            package_name=package_name,
            package_version=package_version,
        )

        vetted_packages_ref.additional_properties = d
        return vetted_packages_ref

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.duration import Duration


T = TypeVar("T", bound="OffsetCheckpointFeature")


@_attrs_define
class OffsetCheckpointFeature:
    """
    Attributes:
        max_offset_checkpoint_emission_delay (Duration | Unset):
    """

    max_offset_checkpoint_emission_delay: Duration | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        max_offset_checkpoint_emission_delay: dict[str, Any] | Unset = UNSET
        if not isinstance(self.max_offset_checkpoint_emission_delay, Unset):
            max_offset_checkpoint_emission_delay = (
                self.max_offset_checkpoint_emission_delay.to_dict()
            )

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if max_offset_checkpoint_emission_delay is not UNSET:
            field_dict["maxOffsetCheckpointEmissionDelay"] = (
                max_offset_checkpoint_emission_delay
            )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.duration import Duration

        d = dict(src_dict)
        _max_offset_checkpoint_emission_delay = d.pop(
            "maxOffsetCheckpointEmissionDelay", UNSET
        )
        max_offset_checkpoint_emission_delay: Duration | Unset
        if isinstance(_max_offset_checkpoint_emission_delay, Unset):
            max_offset_checkpoint_emission_delay = UNSET
        else:
            max_offset_checkpoint_emission_delay = Duration.from_dict(
                _max_offset_checkpoint_emission_delay
            )

        offset_checkpoint_feature = cls(
            max_offset_checkpoint_emission_delay=max_offset_checkpoint_emission_delay,
        )

        offset_checkpoint_feature.additional_properties = d
        return offset_checkpoint_feature

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .pruning_pb2 import ClearScheduleRequest, ClearScheduleResponse, FindPruningTimestampRequest, FindPruningTimestampResponse, GetNoWaitCommitmentsFromRequest, GetNoWaitCommitmentsFromResponse, GetParticipantScheduleRequest, GetParticipantScheduleResponse, GetScheduleRequest, GetScheduleResponse, ParticipantPruningSchedule, PruningSchedule, ResetNoWaitCommitmentsFromRequest, ResetNoWaitCommitmentsFromResponse, SetCronRequest, SetCronResponse, SetMaxDurationRequest, SetMaxDurationResponse, SetNoWaitCommitmentsFromRequest, SetNoWaitCommitmentsFromResponse, SetParticipantScheduleRequest, SetParticipantScheduleResponse, SetRetentionRequest, SetRetentionResponse, SetScheduleRequest, SetScheduleResponse, Synchronizers, WaitCommitmentsSetup

__all__ = [
    "ClearScheduleRequest",
    "ClearScheduleResponse",
    "FindPruningTimestampRequest",
    "FindPruningTimestampResponse",
    "GetNoWaitCommitmentsFromRequest",
    "GetNoWaitCommitmentsFromResponse",
    "GetParticipantScheduleRequest",
    "GetParticipantScheduleResponse",
    "GetScheduleRequest",
    "GetScheduleResponse",
    "ParticipantPruningSchedule",
    "PruningSchedule",
    "ResetNoWaitCommitmentsFromRequest",
    "ResetNoWaitCommitmentsFromResponse",
    "SetCronRequest",
    "SetCronResponse",
    "SetMaxDurationRequest",
    "SetMaxDurationResponse",
    "SetNoWaitCommitmentsFromRequest",
    "SetNoWaitCommitmentsFromResponse",
    "SetParticipantScheduleRequest",
    "SetParticipantScheduleResponse",
    "SetRetentionRequest",
    "SetRetentionResponse",
    "SetScheduleRequest",
    "SetScheduleResponse",
    "Synchronizers",
    "WaitCommitmentsSetup",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.vetted_package import VettedPackage


T = TypeVar("T", bound="ListVettedPackagesResponse")


@_attrs_define
class ListVettedPackagesResponse:
    """
    Attributes:
        next_page_token (str): Pagination token to fetch the next page.
        vetted_packages (list[VettedPackage]): List of vetted packages.
    """

    next_page_token: str
    vetted_packages: list[VettedPackage]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        next_page_token = self.next_page_token

        vetted_packages = []
        for vetted_packages_item_data in self.vetted_packages:
            vetted_packages_item = vetted_packages_item_data.to_dict()
            vetted_packages.append(vetted_packages_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "nextPageToken": next_page_token,
                "vettedPackages": vetted_packages,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.vetted_package import VettedPackage

        d = dict(src_dict)
        next_page_token = d.pop("nextPageToken", "")

        vetted_packages = []
        _vetted_packages = d.pop("vettedPackages", [])
        for vetted_packages_item_data in _vetted_packages:
            vetted_packages_item = VettedPackage.from_dict(vetted_packages_item_data)
            vetted_packages.append(vetted_packages_item)

        list_vetted_packages_response = cls(
            next_page_token=next_page_token,
            vetted_packages=vetted_packages,
        )

        list_vetted_packages_response.additional_properties = d
        return list_vetted_packages_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
"""A client library for accessing JSON Ledger API HTTP endpoints"""

from .client import AuthenticatedClient, Client

__all__ = (
    "AuthenticatedClient",
    "Client",
)
